// example header file

// To include it in the sdist tar.gz file, a MANIFEST.IN file must
// be provided. 


// hello return a heap allocated string containing the name appended 
// to "hello " and terminated by "!".
char* hello(char *name);
